Crate bioyino_metric

Crate bioyino_metric 

This crate contains useful types and methods for working with metrics in bioyino statsd server and some other metric processing software. Features:

  • a type for representing typed and timestamped metrics, generic over floating point format
  • streaming parser of statsd format
  • metric aggregation routines
  • working with Graphite-compatible metric naming including basic tags support
  • schema and functions for sending/receiving metrics in binary Cap’n’Proto format

Re-exports

pub use crate::name::MetricName;
pub use crate::metric::*;
pub use crate::prelude::*;

Modules

aggregate
Aggregation routines
metric
Metric values routines
name
Metric name routines
parser
Metric parsing routines
prelude
Convenience types
protocol_capnp
An autogenerated module for working with capnp schema
protocol_v2_capnp
An autogenerated module for working with capnp schema version 2